// Author: Jim Valavanis, 
// E-Mail: jimmyvalavanis@yahoo.gr
// Site  : http://www.geocities.com/jimmyvalavanis/

unit TipsDlg;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  ExtCtrls, StdCtrls, AppEvnts;

type
  TTipsForm = class(TForm)
    StartUp: TCheckBox;
    TourButton: TButton;
    WhatsNewButton: TButton;
    OLRegButton: TButton;
    ProdCatButton: TButton;
    NextButton: TButton;
    CloseButton: TButton;
    Bevel1: TBevel;
    HintPanel: TPanel;
    DidYouKnow: TLabel;
    Image: TImage;
    Tip: TLabel;
    TipsMemo: TMemo;
    ApplicationEvents1: TApplicationEvents;
    procedure NextButtonClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure ApplicationEvents1Activate(Sender: TObject);
  public
    { Public declarations }
    procedure NextTip;
  end;

  TTipsDialog = class(TComponent)
  private
    FStartUp: boolean;
    FTips: TStrings;
    FTipIndex: integer;
    FDialogCaption: string;
    FDidYouKnowCaption: string;
    procedure SetTips(Value: TStrings);
  protected
    TipsForm: TTipsForm;
  public
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
    // returns FStartUp;
    function Execute:boolean;
  published
    property StartUp: boolean read FStartUp write FStartUp;
    property Tips: TStrings read FTips write SetTips;
    property TipIndex: integer read FTipIndex write FTipIndex default 0;
    property DialogCaption: string read FDialogCaption write FDialogCaption;
    property DidYouKnowCaption: string read FDidYouKnowCaption write FDidYouKnowCaption;
  end;

procedure Register;

implementation

{$R *.DFM}

resourceString
  rsDialogCaption = 'Tip of the day';
  rsDidYouKnowCaption = 'Did you know...';
  rsNoTips = 'Internal error: No tips!';

constructor TTipsDialog.Create;
begin
  inherited Create(AOwner);
  randomize;
  FTips := TStringList.Create;
  FStartUp := False;
  TipIndex := 0;
  FDialogCaption := rsDialogCaption;
  FDidYouKnowCaption := rsDidYouKnowCaption;
end;

destructor TTipsDialog.Destroy;
begin
  FTips.Free;
  inherited Destroy;
end;

procedure TTipsDialog.SetTips;
begin
  FTips.Assign(Value);
end;

function TTipsDialog.Execute: boolean;
begin
  result := false;
  if FTips.Count > 0 then
  begin
    TipsForm := TTipsForm.Create(Self);
    try
      with TipsForm do
      begin
        Caption := FDialogCaption;
        DidYouKnow.Caption := FDidYouKnowCaption;
        StartUp.Checked := FStartUp;
        TipsMemo.Lines.Clear;
        TipsMemo.Lines.AddStrings(FTips);
        if (TipIndex < FTips.Count) and (TipIndex >=0) then
          Tip.Tag := TipIndex
        else
          Tip.Tag := random(FTips.Count);
        if Tip.Tag < FTips.Count then
          Tip.Caption := TipsMemo.Lines[Tip.Tag]
        else
          Tip.Caption := rsNoTips;

        ShowModal;

        FStartup := StartUp.Checked;
        result := FStartup;
        TipIndex := (Tip.Tag + 1)  mod FTips.Count;
      end;
    finally
      TipsForm.Free;
    end;
  end;
end;

procedure TTipsForm.NextButtonClick(Sender: TObject);
begin
  NextTip;
end;

procedure TTipsForm.NextTip;
begin
  if (TipsMemo.Lines.Count > 0) then
  begin
    Tip.Tag := (Tip.Tag + 1) mod TipsMemo.Lines.Count;
    // Make some shots...
    if TipsMemo.Lines[Tip.Tag] = '' then
      Tip.Tag := (Tip.Tag + 1) mod TipsMemo.Lines.Count;
    if TipsMemo.Lines[Tip.Tag] = '' then
      Tip.Tag := (Tip.Tag + 1) mod TipsMemo.Lines.Count;
    if TipsMemo.Lines[Tip.Tag] = '' then
      Tip.Tag := (Tip.Tag + 1) mod TipsMemo.Lines.Count;
    Tip.Caption := TipsMemo.Lines[Tip.Tag];
  end;
end;

procedure TTipsForm.FormCreate(Sender: TObject);
begin
  Icon := Application.Icon;
end;

procedure Register;
begin
  RegisterComponents('JimValavanis', [TTipsDialog]);
end;

procedure TTipsForm.ApplicationEvents1Activate(Sender: TObject);
begin
  if Visible then BringToFront
end;

end.
